Coverage for scipy\linalg\linalg_version.py: 0%

# Coverage for scipy\linalg\linalg_version.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 | from __future__ import division, print_function, absolute_import major = 0 minor = 4 micro = 9 linalg_version = '%(major)d.%(minor)d.%(micro)d' % (locals())